@@ -634,34 +634,6 @@ class Dcim(object):
         """
         return self.netbox_con.get('/dcim/interface-connections/', **kwargs)
 
-    def create_interface_connection(self, interface_a, interface_b, **kwargs):
-        """Create a new interface-connection
-
-        :param interface_a: id of the source interface
-        :param interface_b: id of the destination interface
-        :param kwargs:
-        :return:
-        """
-        required_fields = {"interface_a": interface_a, "interface_b": interface_b}
-        return self.netbox_con.post('/dcim/interface-connections/', required_fields, **kwargs)
-
-    def delete_interface_connection(self, interface_connection_id):
-        """Delete interface-connection by id
-
-        :param interface_connection_id: id of interface-connection to remove
-        :return: bool True if successful otherwise raise DeleteException
-        """
-        return self.netbox_con.delete('/dcim/interface-connections/', interface_connection_id)
-
-    def update_interface_connection(self, interface_connection_id, **kwargs):
-        """Update interface connection
-
-        :param interface_connection_id: interface_connection to update
-        :param kwargs: requests body dict
-        :return: bool True if successful otherwise raise UpdateException
-        """
-        return self.netbox_con.patch('/dcim/interface-connections/', interface_connection_id, **kwargs)
-
     def get_interface_templates(self, **kwargs):
         """Return interface templates"""
         return self.netbox_con.get('/dcim/interface-templates', **kwargs)
